"""Tests for the views of the ``multilingual_events`` app."""
from django.test import TestCase, RequestFactory

from ..factories import EventFactory
from ...views import EventDetailView, EventListView


class EventListViewTestCase(TestCase):
    """Tests for the ``EventListView`` view class."""
    def test_view(self):
        req = RequestFactory().get('/')
        resp = EventListView.as_view()(req)
        self.assertEqual(resp.status_code, 200)


class EventDetailViewTestCase(TestCase):
    """Tests for the ``EventDetailView`` view class."""
    def test_view(self):
        event = EventFactory()
        req = RequestFactory().get('/')
        resp = EventDetailView.as_view()(req, pk=event.pk)
        self.assertEqual(resp.status_code, 200)



"""Registering translated models for the ``multilingual_events`` app."""
from simple_translation.translation_pool import translation_pool

from . import models


translation_pool.register_translation(
    models.EventCategory, models.EventCategoryTitle)
translation_pool.register_translation(models.Event, models.EventTitle)



"""Tests for the models of the ``multilingual_events`` app."""
from mock import Mock
from django.test import TestCase
from django.utils import timezone

from ..models import Event
from .factories import EventFactory, EventTitleFactory, EventPluginModelFactory


class EventManagerTestCase(TestCase):
    """Tests for the ``EventManager`` class."""
    longMessage = True

    def setUp(self):
        # the following two events should be visible
        # a visible event
        EventTitleFactory()

        # a past event with future end date
        past = timezone.now() - timezone.timedelta(1)
        future = timezone.now() + timezone.timedelta(1)
        EventTitleFactory(event__start_date=past, event__end_date=future)

        # the following two events should be invisible
        # an invisible event
        EventTitleFactory(is_published=False)

        # a past event
        past = timezone.now() - timezone.timedelta(1)
        EventTitleFactory(event__start_date=past)

    def test_get_visible_and_get_archived(self):
        manager = Event.objects

        request = Mock(LANGUAGE_CODE='en')
        result = manager.get_upcoming(request)
        self.assertEqual(result.count(), 2)

        result = manager.get_archived(request)
        self.assertEqual(result.count(), 1)

        # another past event
        past = timezone.now() - timezone.timedelta(1)
        EventTitleFactory(event__start_date=past)

        result = manager.get_archived(request)
        self.assertEqual(result.count(), 2)


class EventTestCase(TestCase):
    """Tests for the ``Event`` model class."""
    longMessage = True

    def test_model(self):
        instance = EventFactory()
        self.assertTrue(instance.pk, msg=(
            'Should be able to instantiate and save the model.'))


class EventPluginModelTestCase(TestCase):
    """Tests for the ``EventPluginModel`` model."""
    longMessage = True

    def test_model(self):
        obj = EventPluginModelFactory()
        self.assertTrue(obj.pk, msg=(
            'Should be able to instantiate and save the model.'))


class EventTitleTestCase(TestCase):
    """Tests for the ``EventTitle`` model class."""
    longMessage = True

    def test_model(self):
        instance = EventTitleFactory()
        self.assertTrue(instance.pk, msg=(
            'Should be able to instantiate and save the model.'))



"""Templatetags for the ``multilingual_events`` app."""
from django import template

from ..models import EventCategory, Event


register = template.Library()


@register.assignment_tag
def get_event_categories():
    """Returns all categories in the database."""
    return EventCategory.objects.all().order_by('position')


@register.assignment_tag(takes_context=True)
def get_events(context, amount=5):
    """
    Returns upcoming and currently running events.

    :param request: The current request.
    :param amount: The number of events that should be returned.

    """
    request = context.get('request')
    qs = Event.objects.get_upcoming(request)
    if not qs.count():
        return qs
    return qs[:amount]



"""Models for the ``multilingual_events`` app."""
from django.conf import settings
from django.core.urlresolvers import reverse
from django.db import models
from django.db.models import Q
from django.utils import timezone
from django.utils.translation import get_language
from django.utils.translation import ugettext_lazy as _

from cms.models import CMSPlugin
from django_countries import CountryField
from django_libs.models_mixins import SimpleTranslationMixin
from djangocms_utils.fields import M2MPlaceholderField
from simple_translation.actions import SimpleTranslationPlaceholderActions
from simple_translation.utils import get_preferred_translation_from_lang

from .settings import DISPLAY_TYPE_CHOICES


lat_lng_help_text = _(
    'You can figure out latitude and longitude at'
    ' <a href="http://universimmedia.pagesperso-orange.fr/geo/loc.htm"'
    ' target="_blank">this website</a>')


class EventCategory(SimpleTranslationMixin, models.Model):
    """
    Events are grouped in categories.

    For translateable fields see ``EventCategoryTitle``.

    :position: Use this if you want to change the ordering of categories.

    """
    position = models.PositiveIntegerField(
        verbose_name=_('Position'),
        null=True, blank=True,
    )

    slug = models.CharField(
        max_length=32,
        verbose_name=_('Slug'),
    )

    def __unicode__(self):
        return self.get_translation().title


class EventCategoryTitle(models.Model):
    """
    Translateable fields of the ``EventCategory`` model.

    """
    title = models.CharField(
        max_length=256,
        verbose_name=_('Title'),
    )

    # Needed by simple-translation
    category = models.ForeignKey(EventCategory, verbose_name=_('Category'))
    language = models.CharField(max_length=2, verbose_name=_('Language'))


class EventManager(models.Manager):
    """Custom manager for the ``Event`` model."""
    def get_archived(self, request):
        language = getattr(request, 'LANGUAGE_CODE', None)
        if not language:
            return self.model.objects.none()

        qs = self.get_query_set()
        qs = qs.filter(
            eventtitle__is_published=True,
            eventtitle__language=language,
        )
        qs = qs.filter(
            Q(start_date__lt=timezone.now()) & (
                Q(end_date__isnull=True) | Q(end_date__lt=timezone.now())))
        return qs.distinct()

    def get_upcoming(self, request):
        language = getattr(request, 'LANGUAGE_CODE', None)
        if not language:
            return self.model.objects.none()

        qs = self.get_query_set()
        qs = qs.filter(
            eventtitle__is_published=True,
            eventtitle__language=language,
        )
        qs = qs.filter(
            Q(end_date__gte=timezone.now()) |
            Q(start_date__gte=timezone.now()))
        return qs.distinct()


class Event(SimpleTranslationMixin, models.Model):
    """
    An event is something that happens on a specific start date.

    For translateable fields see ``EventTitle``.

    :start_date: The DateTime when this event starts.
    :creation_date: The DateTime when this event was created.
    :user: The user who created this event.

    """

    placeholders = M2MPlaceholderField(
        actions=SimpleTranslationPlaceholderActions(),
        placeholders=('conference', 'detailed_description'),
    )

    # Allow null for once but remove this later, when data is setup.
    category = models.ForeignKey(
        EventCategory,
        verbose_name=_('Category'),
    )

    start_date = models.DateField(
        verbose_name=_('Start date'),
    )

    start_time = models.TimeField(
        verbose_name=_('Start time'),
        null=True, blank=True,
    )

    end_date = models.DateField(
        verbose_name=_('End date'),
        null=True, blank=True
    )

    end_time = models.TimeField(
        verbose_name=_('End time'),
        null=True, blank=True,
    )

    timezone = models.CharField(
        max_length=65,
        verbose_name=_('Timezone'),
        blank=True,
    )

    url = models.URLField(
        verbose_name=_('External URL'),
        blank=True,
    )

    url_name = models.CharField(
        max_length=256,
        verbose_name=_('External URL name'),
        blank=True,
    )

    venue_url = models.URLField(
        verbose_name=_('Venue URL'),
        blank=True,
    )

    lat = models.FloatField(
        verbose_name=_('Latitude'),
        help_text=lat_lng_help_text,
        null=True, blank=True,
    )

    lng = models.FloatField(
        verbose_name=_('Longitude'),
        help_text=lat_lng_help_text,
        null=True, blank=True,
    )

    creation_date = models.DateTimeField(
        auto_now_add=True,
        verbose_name=('Creation date'),
    )

    last_update = models.DateTimeField(
        auto_now=True,
    )

    user = models.ForeignKey(
        'auth.User',
        verbose_name=_('User'),
        null=True, blank=True,
    )

    country = CountryField(
        verbose_name=_('Country'),
        null=True, blank=True,
    )

    objects = EventManager()

    class Meta:
        ordering = ('start_date', )

    def __unicode__(self):
        return self.get_title()

    def get_address(self):
        """Returns the address with country."""
        trans = self.get_translation()
        full_address = u''
        if trans.venue_name:
            full_address += u'{0}<br />'.format(trans.venue_name)
        if trans.address_1:
            full_address += u'{0}<br />'.format(trans.address_1)
        if trans.address_2:
            full_address += u'{0}<br />'.format(trans.address_2)
        if trans.city:
            if trans.postal_code:
                full_address += u'{0} '.format(trans.postal_code)
            full_address += u'{0}<br />'.format(trans.city)
        full_address += u'{0}'.format(unicode(self.country.name))
        return full_address

    def get_alternative_events(self):
        return Event.objects.filter(category=self.category).exclude(
            pk=self.pk).order_by('start_date')

    def get_city_and_country(self):
        trans = self.get_translation()
        result = u''
        if trans.city:
            result += u'{0}, '.format(trans.city)
        result += unicode(self.country.name)
        return result

    def get_number_of_days(self):
        """Returns the number of days for this event."""
        if not self.end_date:
            return 1
        amount = self.end_date - self.start_date
        return amount.days + 1

    def get_title(self):
        lang = get_language()
        return get_preferred_translation_from_lang(self, lang).title


class EventPluginModel(CMSPlugin):
    """
    Model for the ``EventPlugin`` cms plugin.

    :display_type: The way the plugin is displayed. E.g. 'big' or 'small'
    :event: The event this plugin shows.

    """
    display_type = models.CharField(
        max_length=256,
        choices=DISPLAY_TYPE_CHOICES,
        verbose_name=_('Display type'),
    )
    event = models.ForeignKey(
        Event,
        verbose_name=_('Event'),
    )

    def __unicode__(self):
        return '{} ({})'.format(self.event, self.event.category)


class EventTitle(models.Model):
    """
    Translateable fields of the ``Event`` model.

    :title: Title off the event.
    :venue_name: The venue, this event takes place.
    :city: The city the event will be in.
    :postal_code: The postal code of the city:
    :address_1: The address of the event.
    :address_2: An additional address of the event.
    :room: The room this event will be in.
    :description: A description of the event
    :is_published: If ``True``, the event would be returned by the
      ``get_events`` templatetag.

    """
    title = models.CharField(
        max_length=512,
        verbose_name=_('Title'),
    )

    venue_name = models.CharField(
        max_length=256,
        verbose_name=_('Venue name'),
        blank=True,
    )

    city = models.CharField(
        max_length=256,
        verbose_name=_('City'),
        blank=True,
    )

    postal_code = models.CharField(
        max_length=256,
        verbose_name=_('Postal code'),
        blank=True,
    )

    address_1 = models.CharField(
        max_length=256,
        verbose_name=_('Address 1'),
        blank=True,
    )

    address_2 = models.CharField(
        max_length=256,
        verbose_name=_('Address 2'),
        blank=True,
    )

    room = models.CharField(
        max_length=256,
        verbose_name=_('Block / Room'),
        blank=True,
    )

    description = models.TextField(
        verbose_name=_('Description'),
        blank=True,
    )

    is_published = models.BooleanField(
        default=False,
        verbose_name=_('Is published'),
    )

    # Needed by simple_translation
    event = models.ForeignKey(Event, verbose_name=_('Event'))
    language = models.CharField(max_length=5, verbose_name=('Language'))

    def get_absolute_url(self):
        middleware = (
            'simple_translation.middleware.MultilingualGenericsMiddleware')
        language_namespace = middleware in settings.MIDDLEWARE_CLASSES \
            and '%s:' % self.language or ''
        return reverse(
            '%smultilingual_events_detail' % language_namespace,
            args=(),
            kwargs={'pk': self.event.pk, }
        )


class EventAgendaDay(CMSPlugin):
    """The day and title of an event."""
    date = models.DateField(
        verbose_name=_('Date'),
    )

    title = models.CharField(
        max_length=256,
        verbose_name=_('Title'),
    )

    def __unicode__(self):
        return self.title


class EventAgendaSession(CMSPlugin):
    """A day can consist of several sessions."""
    start_time = models.DateTimeField(
        verbose_name=_('Start time'),
    )

    end_time = models.DateTimeField(
        verbose_name=_('End time'),
    )

    title = models.CharField(
        max_length=256,
        verbose_name=_('Title'),
    )

    description = models.TextField(
        max_length=4000,
        verbose_name=_('Description'),
        blank=True,
    )

    document = models.ForeignKey(
        'document_library.Document',
        verbose_name=_('Document'),
        null=True, blank=True,
    )


class EventAgendaTalk(CMSPlugin):
    """A session can have several talks."""
    title = models.CharField(
        max_length=256,
        verbose_name=_('Title'),
    )

    description = models.TextField(
        max_length=4000,
        verbose_name=_('Description'),
        blank=True,
    )

    document = models.ForeignKey(
        'document_library.Document',
        verbose_name=_('Document'),
        null=True, blank=True,
    )



"""URLs for the ``multilingual_events`` app."""
from django.conf.urls.defaults import patterns, url

from .views import EventDetailView, EventListView


urlpatterns = patterns(
    '',
    url(r'^$',
        EventListView.as_view(),
        name='multilingual_events_list'),

    url(r'^(?P<pk>\d+)/$',
        EventDetailView.as_view(),
        name='multilingual_events_detail'),
)



# flake8: noqa
# -*- coding: utf-8 -*-
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):
        # Adding field 'Event.url'
        db.add_column('multilingual_events_event', 'url',
                      self.gf('django.db.models.fields.URLField')(default='', max_length=200, blank=True),
                      keep_default=False)


    def backwards(self, orm):
        # Deleting field 'Event.url'
        db.delete_column('multilingual_events_event', 'url')


    models = {
        'auth.group': {
            'Meta': {'object_name': 'Group'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '80'}),
            'permissions': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Permission']", 'symmetrical': 'False', 'blank': 'True'})
        },
        'auth.permission': {
            'Meta': {'ordering': "('content_type__app_label', 'content_type__model', 'codename')", 'unique_together': "(('content_type', 'codename'),)", 'object_name': 'Permission'},
            'codename': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'content_type': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['contenttypes.ContentType']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '50'})
        },
        'auth.user': {
            'Meta': {'object_name': 'User'},
            'date_joined': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            'email': ('django.db.models.fields.EmailField', [], {'max_length': '75', 'blank': 'True'}),
            'first_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'blank': 'True'}),
            'groups': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Group']", 'symmetrical': 'False', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'is_active': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'is_staff': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'is_superuser': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'last_login': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            'last_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'blank': 'True'}),
            'password': ('django.db.models.fields.CharField', [], {'max_length': '128'}),
            'user_permissions': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Permission']", 'symmetrical': 'False', 'blank': 'True'}),
            'username': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '30'})
        },
        'cms.cmsplugin': {
            'Meta': {'object_name': 'CMSPlugin'},
            'changed_date': ('django.db.models.fields.DateTimeField', [], {'auto_now': 'True', 'blank': 'True'}),
            'creation_date': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime(2013, 2, 25, 0, 0)'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'language': ('django.db.models.fields.CharField', [], {'max_length': '15', 'db_index': 'True'}),
            'level': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'lft': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'parent': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['cms.CMSPlugin']", 'null': 'True', 'blank': 'True'}),
            'placeholder': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['cms.Placeholder']", 'null': 'True'}),
            'plugin_type': ('django.db.models.fields.CharField', [], {'max_length': '50', 'db_index': 'True'}),
            'position': ('django.db.models.fields.PositiveSmallIntegerField', [], {'null': 'True', 'blank': 'True'}),
            'rght': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}),
            'tree_id': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'})
        },
        'cms.placeholder': {
            'Meta': {'object_name': 'Placeholder'},
            'default_width': ('django.db.models.fields.PositiveSmallIntegerField', [], {'null': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'slot': ('django.db.models.fields.CharField', [], {'max_length': '50', 'db_index': 'True'})
        },
        'contenttypes.contenttype': {
            'Meta': {'ordering': "('name',)", 'unique_together': "(('app_label', 'model'),)", 'object_name': 'ContentType', 'db_table': "'django_content_type'"},
            'app_label': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'model': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        },
        'document_library.document': {
            'Meta': {'ordering': "('position', '-creation_date')", 'object_name': 'Document'},
            'category': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['document_library.DocumentCategory']", 'null': 'True', 'blank': 'True'}),
            'creation_date': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            'download_url': ('django.db.models.fields.URLField', [], {'max_length': '200', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'is_on_front_page': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'is_published': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'position': ('django.db.models.fields.PositiveIntegerField', [], {'null': 'True', 'blank': 'True'}),
            'source_url': ('django.db.models.fields.URLField', [], {'max_length': '200', 'blank': 'True'}),
            'user': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['auth.User']", 'null': 'True', 'blank': 'True'})
        },
        'document_library.documentcategory': {
            'Meta': {'object_name': 'DocumentCategory'},
            'creation_date': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'slug': ('django.db.models.fields.SlugField', [], {'max_length': '32'})
        },
        'multilingual_events.event': {
            'Meta': {'ordering': "('start_date',)", 'object_name': 'Event'},
            'category': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['multilingual_events.EventCategory']"}),
            'country': ('django_countries.fields.CountryField', [], {'max_length': '2', 'null': 'True', 'blank': 'True'}),
            'creation_date': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            'end_date': ('django.db.models.fields.DateField', [], {'null': 'True', 'blank': 'True'}),
            'end_time': ('django.db.models.fields.TimeField', [], {'null': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'is_published': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'placeholders': ('djangocms_utils.fields.M2MPlaceholderField', [], {'to': "orm['cms.Placeholder']", 'symmetrical': 'False'}),
            'start_date': ('django.db.models.fields.DateField', [], {}),
            'start_time': ('django.db.models.fields.TimeField', [], {'null': 'True', 'blank': 'True'}),
            'timezone': ('django.db.models.fields.CharField', [], {'max_length': '65', 'blank': 'True'}),
            'url': ('django.db.models.fields.URLField', [], {'max_length': '200', 'blank': 'True'}),
            'user': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['auth.User']", 'null': 'True', 'blank': 'True'})
        },
        'multilingual_events.eventagendaday': {
            'Meta': {'object_name': 'EventAgendaDay', 'db_table': "'cmsplugin_eventagendaday'", '_ormbases': ['cms.CMSPlugin']},
            'cmsplugin_ptr': ('django.db.models.fields.related.OneToOneField', [], {'to': "orm['cms.CMSPlugin']", 'unique': 'True', 'primary_key': 'True'}),
            'date': ('django.db.models.fields.DateField', [], {}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '256'})
        },
        'multilingual_events.eventagendasession': {
            'Meta': {'object_name': 'EventAgendaSession', 'db_table': "'cmsplugin_eventagendasession'", '_ormbases': ['cms.CMSPlugin']},
            'cmsplugin_ptr': ('django.db.models.fields.related.OneToOneField', [], {'to': "orm['cms.CMSPlugin']", 'unique': 'True', 'primary_key': 'True'}),
            'description': ('django.db.models.fields.TextField', [], {'max_length': '4000', 'blank': 'True'}),
            'document': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['document_library.Document']", 'null': 'True', 'blank': 'True'}),
            'end_time': ('django.db.models.fields.DateTimeField', [], {}),
            'start_time': ('django.db.models.fields.DateTimeField', [], {}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '256'})
        },
        'multilingual_events.eventagendatalk': {
            'Meta': {'object_name': 'EventAgendaTalk', 'db_table': "'cmsplugin_eventagendatalk'", '_ormbases': ['cms.CMSPlugin']},
            'cmsplugin_ptr': ('django.db.models.fields.related.OneToOneField', [], {'to': "orm['cms.CMSPlugin']", 'unique': 'True', 'primary_key': 'True'}),
            'description': ('django.db.models.fields.TextField', [], {'max_length': '4000', 'blank': 'True'}),
            'document': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['document_library.Document']", 'null': 'True', 'blank': 'True'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '256'})
        },
        'multilingual_events.eventcategory': {
            'Meta': {'object_name': 'EventCategory'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'position': ('django.db.models.fields.PositiveIntegerField', [], {'null': 'True', 'blank': 'True'}),
            'slug': ('django.db.models.fields.CharField', [], {'max_length': '32'})
        },
        'multilingual_events.eventcategorytitle': {
            'Meta': {'object_name': 'EventCategoryTitle'},
            'category': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['multilingual_events.EventCategory']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'language': ('django.db.models.fields.CharField', [], {'max_length': '2'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '256'})
        },
        'multilingual_events.eventtitle': {
            'Meta': {'object_name': 'EventTitle'},
            'address': ('django.db.models.fields.TextField', [], {'max_length': '2000', 'blank': 'True'}),
            'description': ('django.db.models.fields.TextField', [], {'blank': 'True'}),
            'event': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['multilingual_events.Event']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'language': ('django.db.models.fields.CharField', [], {'max_length': '5'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '512'})
        }
    }

    complete_apps = ['multilingual_events']



# flake8: noqa
# -*- coding: utf-8 -*-
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):
        # Adding M2M table for field placeholders on 'Event'
        db.create_table('multilingual_events_event_placeholders', (
            ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True)),
            ('event', models.ForeignKey(orm['multilingual_events.event'], null=False)),
            ('placeholder', models.ForeignKey(orm['cms.placeholder'], null=False))
        ))
        db.create_unique('multilingual_events_event_placeholders', ['event_id', 'placeholder_id'])


    def backwards(self, orm):
        # Removing M2M table for field placeholders on 'Event'
        db.delete_table('multilingual_events_event_placeholders')


    models = {
        'auth.group': {
            'Meta': {'object_name': 'Group'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '80'}),
            'permissions': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Permission']", 'symmetrical': 'False', 'blank': 'True'})
        },
        'auth.permission': {
            'Meta': {'ordering': "('content_type__app_label', 'content_type__model', 'codename')", 'unique_together': "(('content_type', 'codename'),)", 'object_name': 'Permission'},
            'codename': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'content_type': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['contenttypes.ContentType']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '50'})
        },
        'auth.user': {
            'Meta': {'object_name': 'User'},
            'date_joined': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            'email': ('django.db.models.fields.EmailField', [], {'max_length': '75', 'blank': 'True'}),
            'first_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'blank': 'True'}),
            'groups': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Group']", 'symmetrical': 'False', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'is_active': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'is_staff': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'is_superuser': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'last_login': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            'last_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'blank': 'True'}),
            'password': ('django.db.models.fields.CharField', [], {'max_length': '128'}),
            'user_permissions': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Permission']", 'symmetrical': 'False', 'blank': 'True'}),
            'username': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '30'})
        },
        'cms.placeholder': {
            'Meta': {'object_name': 'Placeholder'},
            'default_width': ('django.db.models.fields.PositiveSmallIntegerField', [], {'null': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'slot': ('django.db.models.fields.CharField', [], {'max_length': '50', 'db_index': 'True'})
        },
        'contenttypes.contenttype': {
            'Meta': {'ordering': "('name',)", 'unique_together': "(('app_label', 'model'),)", 'object_name': 'ContentType', 'db_table': "'django_content_type'"},
            'app_label': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'model': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        },
        'multilingual_events.event': {
            'Meta': {'object_name': 'Event'},
            'category': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['multilingual_events.EventCategory']"}),
            'creation_date': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'is_published': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'placeholders': ('djangocms_utils.fields.M2MPlaceholderField', [], {'to': "orm['cms.Placeholder']", 'symmetrical': 'False'}),
            'start_date': ('django.db.models.fields.DateTimeField', [], {}),
            'user': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['auth.User']", 'null': 'True', 'blank': 'True'})
        },
        'multilingual_events.eventcategory': {
            'Meta': {'object_name': 'EventCategory'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'position': ('django.db.models.fields.PositiveIntegerField', [], {'null': 'True', 'blank': 'True'})
        },
        'multilingual_events.eventcategorytitle': {
            'Meta': {'object_name': 'EventCategoryTitle'},
            'category': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['multilingual_events.EventCategory']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'language': ('django.db.models.fields.CharField', [], {'max_length': '2'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '256'})
        },
        'multilingual_events.eventtitle': {
            'Meta': {'object_name': 'EventTitle'},
            'content': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['cms.Placeholder']", 'null': 'True', 'blank': 'True'}),
            'description': ('django.db.models.fields.TextField', [], {'blank': 'True'}),
            'event': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['multilingual_events.Event']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'language': ('django.db.models.fields.CharField', [], {'max_length': '5'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '512'})
        }
    }

    complete_apps = ['multilingual_events']



"""Forms for the ``multilingual_events`` app."""
from django.contrib import admin
from django.contrib.admin.widgets import ForeignKeyRawIdWidget
from django.forms.models import ModelForm

from .models import EventAgendaSession, EventAgendaTalk


class EventAgendaAdminWithDocumentMixin(object):
    """
    Mixin for cms plugins that have a FK to ``document_library.Document``.

    """
    def __init__(self, *args, **kwargs):
        super(EventAgendaAdminWithDocumentMixin, self).__init__(
            *args, **kwargs)
        self.fields['document'].widget = ForeignKeyRawIdWidget(
            self._meta.model._meta.get_field('document').rel, admin.site,
        )


class EventAgendaSessionForm(EventAgendaAdminWithDocumentMixin, ModelForm):
    """Admin form for the ``EventAgendaSession`` plugin."""
    class Meta:
        model = EventAgendaSession


class EventAgendaTalkForm(EventAgendaAdminWithDocumentMixin, ModelForm):
    """Admin form for the ``EventAgendaSession`` plugin."""
    class Meta:
        model = EventAgendaTalk
